@@ -100,8 +100,7 @@ print_dentry(addr, sw, subdir, parent)
 		(de.d_child.next  !=&((struct dentry *)addr)->d_child  )? 'C': '-',
 		(de.d_subdirs.next!=&((struct dentry *)addr)->d_subdirs)? 'S': '-',
 		(de.d_alias.next  !=&((struct dentry *)addr)->d_alias  )? 'A': '-');
-	mprintf(FPTR " ", de.d_op);
-	mprintf(FPTR " ", de.d_sb);
+	mprintf(FPTR " " FPTR " ", de.d_op, de.d_sb);
 #if SUBLEVEL>=4
 	mprintf("%lx ", de.d_vfs_flags);
 #endif
