@@ -13,7 +13,8 @@
 void
 prhead_zone()
 {
-	mprintf(SPTR "   FREE " SPTR "   SIZE NAME\n", "ADDR", "MEM_MAP");
+	mprintf(SPTR" FREEPG "SPTR" "SPTR"  S_PADDR  S_MAPNR   SIZE NAME\n",
+		"ADDR", "PGDAT", "MEM_MAP");
 }
 
 addr_t
@@ -27,8 +28,11 @@ print_zone(addr, full)
 
 	memread(addr, sizeof(zone), &zone, "zone");
 	if (!full) {
-		mprintf(FPTR " %6lx " FPTR " ",
-			addr, zone.free_pages, zone.zone_mem_map);
+		mprintf(FPTR " %6lx " FPTR " " FPTR " ",
+			addr, zone.free_pages,
+			zone.zone_pgdat, zone.zone_mem_map);
+		mprintf("%8lx %8lx ",
+			zone.zone_start_paddr, zone.zone_start_mapnr);
 #ifdef _zone_struct_has_size
 		mprintf("%6lx ", zone.size);
 #else
@@ -37,7 +41,7 @@ print_zone(addr, full)
 #endif
 #endif /*_zone_struct_has_size*/
 		memread((addr_t)zone.name, sizeof(buf), &buf, "name");
-		mprint_str(buf, sizeof(buf));
+		mprintstr(buf, sizeof(buf));
 		mprintf("\n");
 		return 0;
 	}
@@ -78,6 +82,9 @@ print_zone(addr, full)
 		}
 		mprintf(" " FPTR "\n", fp->map);
 	}
+#ifdef _zone_struct_has_wait_table
+	mprintf("wait_table         " FPTR "\n", zone.wait_table);
+#endif
 	mprintf("zone_pgdat         " FPTR "\n", zone.zone_pgdat);
 	mprintf("zone_mem_map       " FPTR "\n", zone.zone_mem_map);
 	mprintf("zone_start_paddr   %lx\n", zone.zone_start_paddr);
@@ -85,7 +92,7 @@ print_zone(addr, full)
 
 	mprintf("name               \"");
 	memread((addr_t)zone.name, sizeof(buf), &buf, "name");
-	mprint_str(buf, sizeof(buf));
+	mprintstr(buf, sizeof(buf));
 	mprintf("\"\n");
 #ifdef _zone_struct_has_size
 	mprintf("size               %lx\n", zone.size);
@@ -141,7 +148,7 @@ print_pglist_data(addr)
 		mprintf(" " FPTR "(", addr + OFFSET(struct pglist_data, node_zones[i]));
 		if (pg.node_zones[i].name) {
 			memread((addr_t)pg.node_zones[i].name, sizeof(buf), &buf, "name");
-			mprint_str(buf, sizeof(buf));
+			mprintstr(buf, sizeof(buf));
 		}
 		mprintf(")");
 	}
