@@ -69,6 +69,7 @@ addr_t
 print_socket(addr)
 	addr_t addr;
 {
+	addr_t waddr;
 	struct socket sock;
 	static const struct bitname sflags[] = {
 		{ 1<<SOCK_ASYNC_NOSPACE,	"async_nospace" },
@@ -90,12 +91,19 @@ print_socket(addr)
 	default:		mprintf("?");		break;
 	}
 	mprintf("\n");
-	mprintf("flags:       "); mprintbit(sflags, sock.flags); mprintf("\n");
+	mprintf("flags:      "); mprintbit(sflags, sock.flags); mprintf("\n");
 	mprintf("ops:         " FPTR "\n", sock.ops);
 	mprintf("inode:       " FPTR "\n", sock.inode);
 	mprintf("fasync_list: " FPTR "\n", sock.fasync_list);
 	mprintf("file:        " FPTR "\n", sock.file);
 	mprintf("sk:          " FPTR "\n", sock.sk);
+	mprintf("wait:       ");
+	waddr = (addr_t)sock.wait.task_list.next;
+	while (waddr && waddr != addr + OFFSET(struct socket, wait.task_list)) {
+		mprintf(" " FPTR, waddr);
+		memread(waddr + OFFSET(struct list_head, next), sizeof(waddr), &waddr, "wait_queue_head");
+	}
+	mprintf("\n");
 	mprintf("type:        %s\n", get_socket_type(sock.type));
 	mprintf("passcread:   %x\n", sock.passcred);
 
