@@ -197,7 +197,11 @@ print_task(addr, full)
 	mprintf("\tgid(,e,s,fs): %5d %5d %5d %5d\n",
 		ts.gid, ts.egid, ts.sgid, ts.fsgid);
 #endif
-	mprintf("\tstart_time: " FPTR "  (jiffies)\n",     ts.start_time);
+	if (sizeof(ts.start_time) == sizeof(addr_t))
+		mprintf("\tstart_time: " FPTR "  (jiffies)\n", ts.start_time);
+	else /* RHL 7.3 or 8.0 */
+		mprintf("\tstart_time: %llx  (jiffies)\n", (u64)ts.start_time);
+
 	mprintf("\tuser:       " FPTR "  (user_struct)\n", ts.user);
 	mprintf("\ttty:        " FPTR "  (tty_struct)\n",  ts.tty);
 	mprintf("\tfs:         " FPTR "  (fs_struct)\n",   ts.fs);
