@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -70,7 +70,7 @@ ext2_inode_info()
 		THROW(usage);
 	}
 	while (args[optind]) {
-		print_ext2_inode_info(getaddr(args[optind]));
+		print_ext2_inode_info(getvalue(args[optind]));
 		optind++;
 	}
 	return 0;
