@@ -10,9 +10,6 @@ PRIVATE addr_t buffer_head();
 const commandtable_t command_buffer_head =
 	{"buffer_head", buffer_head, "[-f] address", "print buffer_head table\n  -f  show detail"};
 
-addr_t hash_table_addr;
-addr_t bh_hash_mask_addr;
-
 extern addr_t print_buffer_head();
 
 PRIVATE addr_t
@@ -20,8 +17,7 @@ buffer_head()
 {
 	int i, c;
 	int full = 0;
-	addr_t addr, hash_table;
-	int bh_hash_mask;
+	addr_t addr;
 	extern void prhead_buffer_head();
 
 	while ((c = getopt(argcnt, args, "f")) != EOF) {
