@@ -8,17 +8,11 @@
 #include <linux/fs.h>
 #include <linux/mm.h>
 #include <linux/mount.h>	/* for vfsmount */
+#include <linux/pagemap.h>	/* for as.flags */
 
 #include "printdev.h"
 #include "flags_fs.h"
 
-void
-mprint_kdev_t(kdev)
-	kdev_t kdev;
-{
-	mprintf("%3d,%-3d", major(kdev), minor(kdev));
-}
-
 void
 mprint_dev_t(dev)
 	dev_t dev;
@@ -29,7 +23,7 @@ mprint_dev_t(dev)
 void
 prhead_dentry()
 {
-	mprintf(SPTR" CNT "SPTR" "SPTR" HLCSA "SPTR" "SPTR" F NAME\n",
+	mprintf(SPTR" CNT "SPTR" "SPTR" HLCSA "SPTR" "SPTR" VF NAME\n",
 		"ADDR", "INODE", "PARENT", "D_OP", "SB");
 }
 
@@ -68,11 +62,8 @@ print_dentry(addr, sw, subdir, parent)
 		(de.d_child.next  !=&((struct dentry *)addr)->d_child  )? 'C': '-',
 		(de.d_subdirs.next!=&((struct dentry *)addr)->d_subdirs)? 'S': '-',
 		(de.d_alias.next  !=&((struct dentry *)addr)->d_alias  )? 'A': '-');
-	mprintf(FPTR " ", de.d_op);
-	mprintf(FPTR " ", de.d_sb);
-#if 1
-	mprintf("%lx ", de.d_vfs_flags);
-#endif
+	mprintf(FPTR " " FPTR " %2lx ", de.d_op, de.d_sb, de.d_vfs_flags);
+
 	if (de.d_name.name == ((struct dentry *)addr)->d_iname)
 		mprintstr(de.d_iname, sizeof(de.d_iname));
 	else if (de.d_name.name == NULL)
@@ -149,7 +140,7 @@ print_file(addr, full)
 void
 prhead_filesystem()
 {
-	mprintf(SPTR"        NAME "SPTR" "SPTR" "SPTR" FLAG\n",
+	mprintf(SPTR"        NAME "SPTR" "SPTR" "SPTR" S FLAG\n",
 		"ADDR", "GET_SB", "KILL_SB", "OWNER");
 }
 
@@ -165,6 +156,12 @@ print_file_system_type(addr)
 	memread((addr_t)fs.name, sizeof(buf), buf, "file system type name");
 
 	mprintf(" %11s " FPTR " " FPTR " " FPTR, buf, fs.get_sb, fs.kill_sb, fs.owner);
+	if ((addr_t)fs.fs_supers.next == addr + OFFSET(struct file_system_type,fs_supers))
+		mprintf(" 0");
+	else if (fs.fs_supers.next == fs.fs_supers.prev)
+		mprintf(" 1");
+	else
+		mprintf(" *");
 	mprintbit(fsflags, fs.fs_flags);
 	mprintf("\n");
 	return (addr_t)fs.next;
@@ -206,7 +203,7 @@ print_inode(addr, full)
 
 	if (full) {
 		mprintf("\trdev:      ");
-		mprint_kdev_t(inode.i_rdev);
+		mprint_dev_t(inode.i_rdev);
 		mprintf("\n");
 		mprintf("\t[amc]time: %08lx  %08lx  %08lx\n",
 			inode.i_atime.tv_sec,
@@ -429,6 +426,11 @@ print_address_space(addr, plist)
 	addr_t paddr, top;
 	addr_t print_page();
 	void prhead_page();
+	static const struct bitname asflags[] = {
+		{ 1 << AS_ENOSPC,	"ENOSPC" },
+		{ 1 << AS_EIO,		"EIO" },
+		{ 0,			NULL }
+	};
 
 	mprintf("ADDR:         " FPTR "\n", addr);
 	memread(addr, sizeof(as), &as, "address_space");
@@ -436,18 +438,21 @@ print_address_space(addr, plist)
 #undef ISEMPTY
 #define ISEMPTY(list) \
 	((addr_t)as.list.next == addr + OFFSET(struct address_space, list))
+
 	mprintf("clean_pages:  ");
 	if (ISEMPTY(clean_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			as.clean_pages.next, as.clean_pages.prev);
+
 	mprintf("dirty_pages:  ");
 	if (ISEMPTY(dirty_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			as.dirty_pages.next, as.dirty_pages.prev);
+
 	mprintf("locked_pages: ");
 	if (ISEMPTY(locked_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
@@ -455,13 +460,22 @@ print_address_space(addr, plist)
 		mprintf(FPTR "  " FPTR "\n",
 			as.locked_pages.next, as.locked_pages.prev);
 
+	mprintf("io_pages:     ");
+	if (ISEMPTY(io_pages))
+		mprintf(SPTR "  " SPTR "\n", "-", "-");
+	else
+		mprintf(FPTR "  " FPTR "\n",
+			as.io_pages.next, as.io_pages.prev);
+
 	mprintf("nrpages:      %8lx\n", as.nrpages);
 	mprintf("ops:          " FPTR "\n", as.a_ops);
 	mprintf("host:         " FPTR "\n", as.host);
-	mprintf("mmap:         " FPTR "\n", as.i_mmap.next);		/*XXX*/
-	mprintf("mmap_shared:  " FPTR "\n", as.i_mmap_shared.next);	/*XXX*/
+	mprintf("mmap:         " FPTR "\n", as.i_mmap.next);
+	mprintf("mmap_shared:  " FPTR "\n", as.i_mmap_shared.next);
+	mprintf("dirty_when:   %lx\n", as.dirtied_when);
 	mprintf("gfp_mask:    ");
-	print_gfp(as.gfp_mask);
+	mprintbit(asflags, as.flags & ~__GFP_BITS_MASK);
+	print_gfp(as.flags & __GFP_BITS_MASK);
 
 	if (plist & 1) {
 		prhead_page();
@@ -492,9 +506,11 @@ print_address_space(addr, plist)
 void
 prhead_block_device()
 {
-	mprintf(SPTR" COUNT   DEV  OPEN BLKSZ "SPTR" "SPTR" SEM C SLP "SPTR"  INODES..\n", "ADDR", "HOLDER", "DISK", "INODE");
+	mprintf(SPTR"   DEV  OPEN BLKSZ "SPTR" "SPTR" "SPTR" "SPTR" SEM C SLP "SPTR"  INODES..\n", "ADDR", "HOLDER", "CONTAINS", "PART", "DISK", "INODE");
 }
 
+int offset_block_device_bd_list = OFFSET(struct block_device, bd_list);
+
 addr_t
 print_block_device(addr, eflag)
 	addr_t addr;
@@ -506,13 +522,13 @@ print_block_device(addr, eflag)
 
 	memread(addr, sizeof(bd), &bd, "block_device");
 	if (eflag == 0 && bd.bd_openers == 0)
-		return (addr_t)bd.bd_hash.next;
+		return (addr_t)bd.bd_list.next;
 
 	mprintf(FPTR " ", addr);
-	mprintf("%5x ", ATOMIC_READ(bd.bd_count));
 	mprint_dev_t(bd.bd_dev);
 	mprintf("%4x %5x", bd.bd_openers, bd.bd_block_size);
-	mprintf(" " FPTR " " FPTR, bd.bd_holder, bd.bd_disk);
+	mprintf(" " FPTR " " FPTR, bd.bd_holder, bd.bd_contains);
+	mprintf(" " FPTR " " FPTR, bd.bd_part, bd.bd_disk);
 	mprintf(" %5d %3d", ATOMIC_READ(bd.bd_sem.count), bd.bd_sem.sleepers);
 
 	mprintf(" " FPTR " ", bd.bd_inode);
@@ -524,7 +540,7 @@ print_block_device(addr, eflag)
 		iaddr = (addr_t)inode.i_devices.next;
 	}
 	mprintf("\n");
-	return (addr_t)bd.bd_hash.next;
+	return (addr_t)bd.bd_list.next;
 }
 
 void
