@@ -5,7 +5,9 @@
 #ifndef PRINTDEV_H
 #define PRINTDEV_H
 
+#if LINUXVER<=25
 extern void mprint_kdev_t(kdev_t kdev);
+#endif
 extern void mprint_dev_t(dev_t dev);
 
 #endif /*PRINTDEV_H*/
