@@ -9,6 +9,11 @@
 #include <string.h>
 #include <unistd.h>
 #include <netinet/in.h>
+
+#ifdef CONF_USE_LKCD
+#include <kl_error.h>
+#endif /*CONF_USE_LKCD*/
+
 #include "crash.h"
 
 PRIVATE addr_t dsymbol();
@@ -28,17 +33,47 @@ addr_t kmem_low = 0;
 addr_t kmem_high = -1;
 addr_t high_memory;
 
+#ifdef CONF_USE_LKCD
+extern char *kerntype;
+
+void *
+kl_get_ra(void)
+{
+	return 0;
+}
+#endif /*CONF_USE_LKCD*/
+
+#ifndef O_LARGEFILE
+#define O_LARGEFILE	0100000
+#endif
+#define OPEN_MODE	(O_RDONLY | O_LARGEFILE)
+
 void
 init_mem()
 {
 	/* open memory device */
 	if (physname) {
-		if ((mem = open(physname, O_RDONLY)) == -1) {
+#ifndef CONF_USE_LKCD
+		if ((mem = open(physname, OPEN_MODE)) == -1) {
 			perror(physname);
 			exit(1);
 		}
+#else /*CONF_USE_LKCD*/
+		if (symname == NULL) {
+			symname = "/boot/System.map";
+		}
+		if (kerntype == NULL) {
+			kerntype = "/boot/Kerntypes";
+		}
+		if (kl_init_klib(symname, physname, kerntype, 0)) {
+			fprintf(stderr, "abort\n");
+			exit(1);
+		}
+		printf("\n");
+		return;
+#endif /*CONF_USE_LKCD*/
 	} else {
-		if ((mem = open("/dev/kmem", O_RDONLY)) == -1) {
+		if ((mem = open("/dev/kmem", OPEN_MODE)) == -1) {
 			perror("/dev/kmem");
 			exit(1);
 		}
@@ -71,6 +106,7 @@ memread(addr, size, buf, errmsg)
 	const char *errmsg;
 {
 	if (physname) {
+#ifndef CONF_USE_LKCD
 		do {
 			addr_t count, paddr;
 			count = size;
@@ -82,6 +118,11 @@ memread(addr, size, buf, errmsg)
 			buf  += count;
 			size -= count;
 		} while (size);
+#else /*CONF_USE_LKCD*/
+		if (get_block(addr, (unsigned)size, buf, 0)) {
+			THROWF("error %lx", KL_ERROR);
+		}
+#endif /*CONF_USE_LKCD*/
 		return;
 #ifdef RESTRICT_KERNEL_MEM
 	} else if (addr < kmem_low) {
@@ -179,7 +220,7 @@ init_sym()
 			continue;
 		if (strcmp(buf, "swapper_pg_dir") == 0)
 			swapper_pg_dir = addr;
-#if LINUXVER == 25
+#if LINUXVER >= 25
 		/* for 2.5 system_call() */
 		if (strcmp(buf, "syscall_call") == 0)
 			continue;
@@ -201,7 +242,12 @@ init_sym()
 	for (i = 0; i < nsym; i++) {
 		const char *p = symtable[i].name? symtable[i].name:
 						  symtable[i].nbuf;
-		if (*p == 'm' && (strcmp(p + 1, "odules_list") == 0 || strcmp(p + 1, "odule_list") == 0)) {
+#if LINUXVER >= 25
+#define MODULE_LIST	"modules"
+#else
+#define MODULE_LIST	"module_list"
+#endif
+		if (strcmp(p, MODULE_LIST) == 0) {
 			get_module_symbol(symtable[i].addr);
 			break;
 		}
@@ -266,6 +312,9 @@ getmsyms_fromfile(path, text, data, bss)
 	addr_t addr;
 	char type;
 
+#if 0
+	mprintf("%s  %lx %lx %lx\n", path, text, data, bss);
+#endif
 	if (path == 0)
 		return 1;
 	if (access(path, R_OK) == -1)
@@ -332,6 +381,7 @@ searchaddr_bysym(name)
 
 	for (pp = &p->next, p = *pp; p != NULL; pp = &p->next, p = *pp) {
 		if (strcmp(p->name, name) == 0) {
+			/* Found! Reorder the list */
 			*pp = p->next;
 			p->next = symhash[n];
 			symhash[n] = p;
@@ -473,7 +523,7 @@ dsymbol()
 }
 
 void
-pmode(aflag)
+mprint_mode(aflag)
 	int aflag;
 {
 	int ltyp;
