@@ -51,9 +51,17 @@ print_xlog(addr)
 	mprintf("prev_cycle     %x\n", log.l_prev_cycle);
 	mprintf("curr_block     %x\n", log.l_curr_block);
 	mprintf("prev_block     %x\n", log.l_prev_block);
-	mprintf("iclog_size     %x\n", log.l_iclog_size);
-	mprintf("iclog_size_log %x\n", log.l_iclog_size_log);
+	mprintf("iclog_size     %x  (2^%d)\n", log.l_iclog_size,
+		log.l_iclog_size_log);
 	mprintf("iclog_bufs     %x\n", log.l_iclog_bufs);
+	mprintf("reserve_headq  " FPTR "  (xlog_ticket)\n", log.l_reserve_headq);
+	mprintf("write_headq    " FPTR "  (xlog_ticket)\n", log.l_write_headq);
+	mprintf("grant_reserve  %x  %x\n",
+		log.l_grant_reserve_cycle,
+		log.l_grant_reserve_bytes);
+	mprintf("grant_write    %x  %x\n",
+		log.l_grant_write_cycle,
+		log.l_grant_write_bytes);
 	mprintf("flags          %x  ", log.l_flags);
 	mprintbit(lflags, log.l_flags);
 	mprintf("\n");
